![Tests](https://github.com/ioannis-vm/OpenSees_Model_Generator/actions/workflows/tests.yml/badge.svg)

# OpenSees Model Generator

![Screenshot](/img/teaser_image.png)

This module aims to assist the definition, analysis, and post-processing of 3D OpenSees models.
Anyone is free and welcome to use, fork, extend and redistribute the code.


[View on PyPI](https://pypi.org/project/osmg/)

Installation:
> pip install osmg
